;; Generated package description from keymap-popup.el  -*- mode: lisp-data; no-byte-compile: t; lexical-binding:t -*-
(define-package "keymap-popup" "0.3.1.0.20260705.33" "Described keymaps with popup help" '((emacs "29.1")) :commit "fe0e538d35e8bb63e165e78506eff3253fd234d8" :authors '(("Thanos Apollo" . "public@thanosapollo.org")) :maintainer '("Thanos Apollo" . "public@thanosapollo.org") :keywords '("convenience") :url "https://codeberg.org/thanosapollo/emacs-keymap-popup")
